@@ -50,16 +50,16 @@ static void
 	         "This utility helps you to start a program on a new virtual terminal (VT).\n"
 	         "\n"
 	         "Options:\n"
-	         "  -c, --console=NUM   use the given VT number;\n"
-	         "  -e, --exec          execute the command, without forking;\n"
-	         "  -f, --force         force opening a VT without checking;\n"
-	         "  -l, --login         make the command a login shell;\n"
-	         "  -u, --user          figure out the owner of the current VT;\n"
-	         "  -s, --switch        switch to the new VT;\n"
-	         "  -w, --wait          wait for command to complete;\n"
-	         "  -v, --verbose       print a message for each action;\n"
-	         "  -V, --version       print program version and exit;\n"
-	         "  -h, --help          output a brief help message.\n"
+	         "  -c, --console=NUM     use the given VT number;\n"
+	         "  -e, --exec            execute the command, without forking;\n"
+	         "  -f, --force           force opening a VT without checking;\n"
+	         "  -l, --login           make the command a login shell;\n"
+	         "  -u, --user            figure out the owner of the current VT;\n"
+	         "  -s, --switch          switch to the new VT;\n"
+	         "  -w, --wait            wait for command to complete;\n"
+	         "  -v, --verbose         explain what is being done;\n"
+	         "  -h, --help            print this usage message;\n"
+	         "  -V, --version         print version number.\n"
 	         "\n"),
 	       get_progname());
 	exit(ret);
