@@ -1,14 +1,16 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <error.h>
 #include <errno.h>
 
 #include <keymap.h>
+#include "libcommon.h"
 
 int
-main(void)
+main(int __attribute__((unused)) argc, char **argv)
 {
+	set_progname(argv[0]);
+
 	int i = MAX_DIACR + 10;
 	struct lk_ctx *ctx;
 	struct lk_kbdiacr ptr;
@@ -22,7 +24,7 @@ main(void)
 
 	while (i > 0) {
 		if (lk_append_diacr(ctx, &ptr) != 0)
-			error(EXIT_FAILURE, 0, "Unable to add diacr");
+			kbd_error(EXIT_FAILURE, 0, "Unable to add diacr");
 		i--;
 	}
 
